@@ -88,26 +88,6 @@ namespace Tomboy.Evolution
 			}
 		}
 
-		//
-		// Duplicates evoluion/camel/camel-url.c:camel_url_encode and
-		// escapes ";?" as well.
-		//
-		static string CamelUrlEncode (string uri_part)
-		{
-			// The characters Camel encodes
-			const string camel_escape_chars = " \"%#<>{}|\\^[]`;?";
-
-			StringBuilder builder = new StringBuilder (null);
-			foreach (char c in uri_part) {
-				if (camel_escape_chars.IndexOf (c) > -1)
-					builder.Append (Uri.HexEscape (c));
-				else
-					builder.Append (c);
-			}
-
-			return builder.ToString ();
-		}
-
 		//
 		// Duplicates
 		// evolution/mail/mail-config.c:mail_config_get_account_by_source_url...
@@ -205,7 +185,11 @@ namespace Tomboy.Evolution
 			if (path != string.Empty) {
 				// Skip leading '/' or '#'...
 				path = path.Substring (1);
-				path = CamelUrlEncode (path);
+				
+				// Some of the special characters in path are escaped (ex: " ",
+				// "%", ...) but other like ";" and "?" are not. This ensures
+				// that all special characters are escaped.
+				path = Uri.EscapeDataString (Uri.UnescapeDataString (path));
 			}
 
 			return string.Format ("email://{0}/{1}", account_uid, path);
@@ -224,6 +208,17 @@ namespace Tomboy.Evolution
 
 	public class EmailLink : DynamicNoteTag
 	{
+		static Gdk.Pixbuf mail_icon = null;
+		
+		static EmailLink ()
+		{
+			mail_icon =
+				GuiUtils.GetIcon (
+					System.Reflection.Assembly.GetExecutingAssembly (),
+					"mail",
+					16);
+		}
+		
 		public EmailLink ()
 : base ()
 		{
@@ -237,7 +232,7 @@ namespace Tomboy.Evolution
 			Foreground = "blue";
 			CanActivate = true;
 
-			Image = new Gdk.Pixbuf (null, "stock_mail.png");
+			Image = mail_icon;
 		}
 
 		public string EmailUri
@@ -486,4 +481,4 @@ namespace Tomboy.Evolution
 		}
 	}
 
-}
\ No newline at end of file
+}
