@@ -15,6 +15,13 @@ namespace Tomboy
 	public delegate void TagRemovingHandler (Note note, Tag tag);
 	public delegate void TagRemovedHandler (Note note, string tag_name);
 
+	public enum ChangeType
+	{
+		NoChange,
+		ContentChanged,
+		OtherDataChanged
+	}
+
 	// Contains all pure note data, like the note title and note text.
 	public class NoteData
 	{
@@ -23,6 +30,7 @@ namespace Tomboy
 		string text;
 		DateTime create_date;
 		DateTime change_date;
+		DateTime metadata_change_date;
 
 		int cursor_pos;
 		int width, height;
@@ -44,6 +52,7 @@ namespace Tomboy
 
 			create_date = DateTime.MinValue;
 			change_date = DateTime.MinValue;
+			metadata_change_date = DateTime.MinValue;
 		}
 
 		public string Uri
@@ -83,6 +92,10 @@ namespace Tomboy
 			}
 		}
 
+		/// <summary>
+		/// Indicates the last time note content data changed.
+		/// Does not include tag/notebook changes (see MetadataChangeDate).
+		/// </summary>
 		public DateTime ChangeDate
 		{
 			get {
@@ -90,9 +103,25 @@ namespace Tomboy
 			}
 			set {
 				change_date = value;
+				metadata_change_date = value;
 			}
 		}
 
+		/// <summary>
+		/// Indicates the last time non-content note data changed.
+		/// This currently only applies to tags/notebooks.
+		/// </summary>
+		public DateTime MetadataChangeDate
+		{
+			get {
+				return metadata_change_date;
+			}
+			set {
+				metadata_change_date = value;
+			}
+		}
+		
+
 		// FIXME: the next five attributes don't belong here (the data
 		// model), but belong into the view; for now they are kept here
 		// for backwards compatibility
@@ -166,8 +195,10 @@ namespace Tomboy
 
 		public void SetPositionExtent (int x, int y, int width, int height)
 		{
-			Debug.Assert (x >= 0 && y >= 0);
-			Debug.Assert (width > 0 && height > 0);
+			if (x < 0 || y < 0)
+				return;
+			if (width <= 0 || height <= 0)
+				return;
 
 			this.x = x;
 			this.y = y;
@@ -322,6 +353,7 @@ namespace Tomboy
 		string filepath;
 
 		bool save_needed;
+		bool is_deleting;
 
 		NoteManager manager;
 		NoteWindow window;
@@ -360,14 +392,43 @@ namespace Tomboy
 			save_timeout.Timeout += SaveTimeout;
 
 			childWidgetQueue = new Queue <ChildWidgetData> ();
+			
+			is_deleting = false;
 		}
-
+		/// <summary>
+		/// Returns a Tomboy URL from the given path.
+		/// </summary>
+		/// <param name="filepath">
+		/// A <see cref="System.String"/>
+		/// </param>
+		/// <returns>
+		/// A <see cref="System.String"/>
+		/// </returns>
 		static string UrlFromPath (string filepath)
 		{
 			return "note://tomboy/" +
 			       Path.GetFileNameWithoutExtension (filepath);
 		}
 
+		public override int GetHashCode ()
+		{
+			return this.Title.GetHashCode();
+		}
+		/// <summary>
+		/// Creates a New Note with the given values.
+		/// </summary>
+		/// <param name="title">
+		/// A <see cref="System.String"/>
+		/// </param>
+		/// <param name="filepath">
+		/// A <see cref="System.String"/>
+		/// </param>
+		/// <param name="manager">
+		/// A <see cref="NoteManager"/>
+		/// </param>
+		/// <returns>
+		/// A <see cref="Note"/>
+		/// </returns>
 		public static Note CreateNewNote (string title,
 		                                  string filepath,
 		                                  NoteManager manager)
@@ -390,8 +451,10 @@ namespace Tomboy
 			return new Note (data, filepath, manager);
 		}
 
+
 		public void Delete ()
 		{
+			is_deleting = true;
 			save_timeout.Cancel ();
 
 			// Remove the note from all the tags
@@ -403,6 +466,8 @@ namespace Tomboy
 				window.Hide ();
 				window.Destroy ();
 			}
+			
+			
 
 			// Remove note URI from GConf entry menu_pinned_notes
 			IsPinned = false;
@@ -419,6 +484,11 @@ namespace Tomboy
 
 		public void Save ()
 		{
+			// Prevent any other condition forcing a save on the note
+			// if Delete has been called.
+			if (is_deleting)
+				return;
+			
 			// Do nothing if we don't need to save.  Avoids unneccessary saves
 			// e.g on forced quit when we call save for every note.
 			if (!save_needed)
@@ -440,14 +510,14 @@ namespace Tomboy
 		void BufferChanged (object sender, EventArgs args)
 		{
 			DebugSave ("BufferChanged queueing save");
-			QueueSave (true);
+			QueueSave (ChangeType.ContentChanged);
 		}
 
 		void BufferTagApplied (object sender, Gtk.TagAppliedArgs args)
 		{
 			if (NoteTagTable.TagIsSerializable (args.Tag)) {
 				DebugSave ("BufferTagApplied queueing save: {0}", args.Tag.Name);
-				QueueSave (true);
+				QueueSave (ChangeType.ContentChanged);
 			}
 		}
 
@@ -455,7 +525,7 @@ namespace Tomboy
 		{
 			if (NoteTagTable.TagIsSerializable (args.Tag)) {
 				DebugSave ("BufferTagRemoved queueing save: {0}", args.Tag.Name);
-				QueueSave (true);
+				QueueSave (ChangeType.ContentChanged);
 			}
 		}
 
@@ -467,7 +537,7 @@ namespace Tomboy
 			data.Data.CursorPosition = args.Location.Offset;
 
 			DebugSave ("BufferInsertSetMark queueing save");
-			QueueSave (false);
+			QueueSave (ChangeType.NoChange);
 		}
 
 		//
@@ -497,7 +567,7 @@ namespace Tomboy
 			data.Data.SetPositionExtent (cur_x, cur_y, cur_width, cur_height);
 
 			DebugSave ("WindowConfigureEvent queueing save");
-			QueueSave (false);
+			QueueSave (ChangeType.NoChange);
 		}
 
 		[GLib.ConnectBefore]
@@ -505,7 +575,7 @@ namespace Tomboy
 		{
 			window = null;
 		}
-
+		
 		/// <summary>
 		/// Set a 4 second timeout to execute the save.  Possibly
 		/// invalidate the text, which causes a re-serialize when the
@@ -513,17 +583,31 @@ namespace Tomboy
 		/// </summary>
 		/// <param name="content_changed">Indicates whether or not
 		/// to update the note's last change date</param>
-		public void QueueSave (bool content_changed)
+		public void QueueSave (ChangeType changeType)
 		{
 			DebugSave ("Got QueueSave");
 
 			// Replace the existing save timeout.  Wait 4 seconds
 			// before saving...
 			save_timeout.Reset (4000);
-			save_needed = true;
-
-			if (content_changed) {
+			if (!is_deleting)
+				save_needed = true;
+			
+			switch (changeType)
+			{
+			case ChangeType.ContentChanged:
+				// NOTE: Updating ChangeDate automatically updates MetdataChangeDate to match.
 				data.Data.ChangeDate = DateTime.Now;
+				break;
+			case ChangeType.OtherDataChanged:
+				// Only update MetadataChangeDate.  Used by sync/etc
+				// to know when non-content note data has changed,
+				// but order of notes in menu and search UI is
+				// unaffected.
+				data.Data.MetadataChangeDate = DateTime.Now;
+				break;
+			default:
+				break;
 			}
 		}
 
@@ -554,7 +638,7 @@ namespace Tomboy
 					TagAdded (this, tag);
 
 				DebugSave ("Tag added, queueing save");
-				QueueSave (true);
+				QueueSave (ChangeType.OtherDataChanged);
 			}
 		}
 
@@ -576,7 +660,15 @@ namespace Tomboy
 				TagRemoved (this, tag.NormalizedName);
 
 			DebugSave ("Tag removed, queueing save");
-			QueueSave (true);
+			QueueSave (ChangeType.OtherDataChanged);
+		}
+		
+		public bool ContainsTag (Tag tag)
+		{
+			if (data.Data.Tags.ContainsKey (tag.NormalizedName) == true)
+				return true;
+			
+			return false;
 		}
 
 		public void AddChildWidget (Gtk.TextChildAnchor childAnchor, Gtk.Widget widget)
@@ -645,7 +737,7 @@ namespace Tomboy
 					if (Renamed != null)
 						Renamed (this, old_title);
 
-					QueueSave (true); // TODO: Right place for this?
+					QueueSave (ChangeType.ContentChanged); // TODO: Right place for this?
 				}
 			}
 		}
@@ -662,7 +754,7 @@ namespace Tomboy
 				if (Renamed != null)
 					Renamed (this, newTitle);
 
-				QueueSave (true); // TODO: Right place for this?
+				QueueSave (ChangeType.ContentChanged); // TODO: Right place for this?
 			}
 		}
 
@@ -746,6 +838,10 @@ namespace Tomboy
 						data.Data.ChangeDate =
 						        XmlConvert.ToDateTime (xml.ReadString (), NoteArchiver.DATE_TIME_FORMAT);
 						break;
+					case "last-metadata-change-date":
+						data.Data.MetadataChangeDate =
+						        XmlConvert.ToDateTime (xml.ReadString (), NoteArchiver.DATE_TIME_FORMAT);
+						break;
 					case "create-date":
 						data.Data.CreateDate =
 						        XmlConvert.ToDateTime (xml.ReadString (), NoteArchiver.DATE_TIME_FORMAT);
@@ -817,12 +913,27 @@ namespace Tomboy
 			}
 		}
 
+		/// <summary>
+		/// Indicates the last time note content data changed.
+		/// Does not include tag/notebook changes (see MetadataChangeDate).
+		/// </summary>
 		public DateTime ChangeDate
 		{
 			get {
 				return data.Data.ChangeDate;
 			}
 		}
+		
+		/// <summary>
+		/// Indicates the last time non-content note data changed.
+		/// This currently only applies to tags/notebooks.
+		/// </summary>
+		public DateTime MetadataChangeDate
+		{
+			get {
+				return data.Data.MetadataChangeDate;
+			}
+		}
 
 		public NoteManager Manager
 		{
@@ -1011,7 +1122,7 @@ namespace Tomboy
 	// since this class is only seldomly used
 	public class NoteArchiver
 	{
-		public const string CURRENT_VERSION = "0.2";
+		public const string CURRENT_VERSION = "0.3";
 
 		public const string DATE_TIME_FORMAT = "yyyy-MM-ddTHH:mm:ss.fffffffzzz";
 
@@ -1075,6 +1186,10 @@ namespace Tomboy
 						note.ChangeDate =
 						        XmlConvert.ToDateTime (xml.ReadString (), DATE_TIME_FORMAT);
 						break;
+					case "last-metadata-change-date":
+						note.MetadataChangeDate =
+						        XmlConvert.ToDateTime (xml.ReadString (), DATE_TIME_FORMAT);
+						break;
 					case "create-date":
 						note.CreateDate =
 						        XmlConvert.ToDateTime (xml.ReadString (), DATE_TIME_FORMAT);
@@ -1109,7 +1224,7 @@ namespace Tomboy
 					break;
 				}
 			}
-
+			reader.Close ();
 			xml.Close ();
 
 			if (version != NoteArchiver.CURRENT_VERSION) {
@@ -1200,6 +1315,11 @@ namespace Tomboy
 			        XmlConvert.ToString (note.ChangeDate, DATE_TIME_FORMAT));
 			xml.WriteEndElement ();
 
+			xml.WriteStartElement (null, "last-metadata-change-date", null);
+			xml.WriteString (
+			        XmlConvert.ToString (note.MetadataChangeDate, DATE_TIME_FORMAT));
+			xml.WriteEndElement ();
+
 			if (note.CreateDate != DateTime.MinValue) {
 				xml.WriteStartElement (null, "create-date", null);
 				xml.WriteString (
@@ -1253,8 +1373,7 @@ namespace Tomboy
 			List<string> tags = new List<string> ();
 
 			foreach (XmlNode node in tagNodes.SelectNodes ("//tag")) {
-				string tag = node.InnerText;
-				tags.Add (tag);
+				tags.Add (node.InnerText);
 			}
 
 			return tags;
@@ -1305,15 +1424,22 @@ namespace Tomboy
 
 	public class NoteUtils
 	{
-		public static void ShowDeletionDialog (Note note, Gtk.Window parent)
+		public static void ShowDeletionDialog (List<Note> notes, Gtk.Window parent)
 		{
+			string message;
+			
+			if (notes.Count == 1)
+				message = Catalog.GetString ("Really delete this note?");
+			else
+				message = Catalog.GetString ("Really delete these notes?");
+			
 			HIGMessageDialog dialog =
 			        new HIGMessageDialog (
 			        parent,
 			        Gtk.DialogFlags.DestroyWithParent,
 			        Gtk.MessageType.Question,
 			        Gtk.ButtonsType.None,
-			        Catalog.GetString ("Really delete this note?"),
+			        message,
 			        Catalog.GetString ("If you delete a note it is " +
 			                           "permanently lost."));
 
@@ -1332,7 +1458,9 @@ namespace Tomboy
 
 			int result = dialog.Run ();
 			if (result == 666) {
-				note.Manager.Delete (note);
+				foreach (Note note in notes) {
+					note.Manager.Delete (note);
+				}
 			}
 
 			dialog.Destroy();
